@@ -20,6 +20,50 @@ test_that("Addition tree is more parsimonious", {
   expect_lt(Score(pr, "pr"), Score(nj10, "pr"))
 })
 
+test_that(".ConstraintConstrains() succeeds", {
+  expect_false(.ConstraintConstrains(NULL))
+  
+  # Single level
+  expect_false(.ConstraintConstrains(
+    structure(list(A = 1L, B = 2L, C = 2L, D = 2L), weight = 1L, nr = 1L,
+              nc = 1L, index = 1L, levels = 0, allLevels = c("0", "?"),
+              type = "USER", contrast = 
+                structure(c(1, 1), dim = 2:1, dimnames = list(NULL, 0)),
+              class = "phyDat")
+  ))
+  
+  expect_false(.ConstraintConstrains(
+    structure(list(A = 1L, B = 2L, C = 1L, D = 1L, E = 3L), weight = 1L, nr = 1L,
+              nc = 2L, index = 1L, levels = 0:1,
+              allLevels = c("0", "1", "?"), type = "USER",
+              contrast = structure(c(1, 0, 1, 0, 1, 1), dim = 3:2,
+                                   dimnames = list(NULL, 0:1)),
+              class = "phyDat")
+  ))
+  expect_true(.ConstraintConstrains(structure(
+    list(A = 1L, B = 2L, C = 1L, D = 1L, E = 3L, F = 2L), weight = 1L, nr = 1L,
+    nc = 2L, index = 1L, levels = 0:1, allLevels = c("0", "1", "?"),
+    type = "USER", contrast = structure(c(1, 0, 1, 0, 1, 1), dim = 3:2,
+                                        dimnames = list(NULL, 0:1)),
+    class = "phyDat")
+  ))
+  expect_false(.ConstraintConstrains(structure(
+    list(A = 1L, B = 2L, C = 1L, D = 1L, E = 3L, F = 2L), weight = 1L, nr = 1L,
+    nc = 2L, index = 1L,
+    levels = 0:2, allLevels = c("0", "1", "2", "?"), type = "USER",
+    contrast = structure(c(1, 1, 0, 1, 0, 1, 0, 1, 0, 0, 1, 1),
+                         dim = c(4, 3), dimnames = list(NULL, 0:2)),
+    class = "phyDat")
+  ))
+  expect_true(.ConstraintConstrains(structure(
+    list(A = 1L, B = 2L, C = 1L, D = 1L, E = 3L, F = 2L), weight = 1L, nr = 1L,
+    nc = 2L, index = 1L, levels = 0:2, allLevels = c("0", "1", "2", "?"),
+    type = "USER", contrast = structure(c(1, 0, 1, 1, 0, 1, 0, 1, 1),
+                                        dim = c(3, 3), dimnames = list(NULL, 0:2)),
+    class = "phyDat")
+  ))
+})
+
 test_that("Addition tree obeys constraints", {
   dataset <- MatrixToPhyDat(matrix(
     c(0, 1, 1, 1, 0, 1,
